API Reference
=============

PELICAN Network
---------------

.. autosummary::
   :toctree: generated/
   :recursive:

   pelican.nets.PELICAN

Permutation-equivariant layers
------------------------------

.. autosummary::
   :toctree: generated/
   :recursive:

   pelican.layers.PELICANBlock
   pelican.layers.Aggregator2to2
   pelican.layers.Aggregator2to1
   pelican.layers.Aggregator2to0
   pelican.layers.Aggregator1to2
   pelican.layers.Aggregator0to2
   pelican.layers.GeneralAggregator

Permutation-equivariant aggregators
-----------------------------------

.. autosummary::
   :toctree: generated/
   :recursive:

   pelican.primitives.aggregate_0to2
   pelican.primitives.aggregate_1to2
   pelican.primitives.aggregate_2to0
   pelican.primitives.aggregate_2to1
   pelican.primitives.aggregate_2to2
